class PacketType:
    """
    Byte-Order: little
    """
    INITIALIZE_CONNECTION = b"\x10\x00"
    INITIALIZE_CONNECTION_RESPONSE = b"\x10\x80"
    START_JOB = b"\x03\x00"
    START_JOB_RESPONSE = b"\x03\x80"
    GET_LANGUAGES = b"\x40\x00"
    GET_LANGUAGES_RESPONSE = b"\x40\x80"
    LIST_PROCESS_VARIABLE = b"\x01\x00"
    LIST_PROCESS_VARIABLE_RESPONSE = b"\x01\x80"
    READ_PROCESS_VARIABLE = b"\x02\x00"
    READ_PROCESS_VARIABLE_RESPONSE = b"\x02\x80"
    END_OF_CYCLE = b"\x20\x00"
    EVENT = b"\x50\x00"
    CYCLE_INTERRUPTION = b"\x21\x00"
    CYCLE_INTERRUPTION_QUERY = b"\x22\x00"
    CYCLE_INTERRUPTION_QUERY_RESPONSE = b"\x22\x80"
    SPC_PARAMETER = b"\x30\x00"
    SPC_PARAMETER_QUERY = b"\x31\x00"
    SPC_PARAMETER_QUERY_RESPONSE = b"\x31\x80"
    MACHINE_STATUS = b"\x70\x00"
    MACHINE_STATUS_RESPONSE = b"\x70\x80"
    UPLOAD_START = b"\x11\x00"
    UPLOAD_START_RESPONSE = b"\x11\x80"
    UPLOAD_DATA = b"\x12\x00"
    UPLOAD_DATA_RESPONSE = b"\x12\x80"
    UPLOAD_END = b"\x13\x00"
    UPLOAD_END_RESPONSE = b"\x13\x80"
    UPLOAD_START_HOST = b"\x14\x00"
    UPLOAD_START_HOST_RESPONSE = b"\x14\x80"
    DOWNLOAD_START = b"\x05\x00"
    DOWNLOAD_START_RESPONSE = b"\x05\x80"
    DOWNLOAD_DATA = b"\x06\x00"
    DOWNLOAD_DATA_RESPONSE = b"\x06\x80"
    DOWNLOAD_END = b"\x07\x00"
    DOWNLOAD_END_RESPONSE = b"\x07\x80"
    ERROR = b"\xff\xff"
